@@ -4,7 +4,7 @@ Usage:
     jish component <component>
     jish version <version>
     jish workon <issue>
-    jish create <issue-type> <details>
+    jish create <issue-type> <details> [--assign-to-me]
     jish deactivate
 
  Options:
@@ -89,6 +89,11 @@ def _jish(argv):
                 environ.get('JISSUE_COMPONENT') or None,
                 environ.get('JISSUE_VERSION'),
                 arguments.get("<details>"))
+        if arguments.get("--assign-to-me"):
+            from .config import Configuration
+            args = args + (Configuration.from_file().username, )
+        else:
+            args = args + (None, )
         arguments.workon = True
         arguments['<issue>'] = jira_adapter.create_issue(*args).key
         set_environment_variables(arguments, environment_variables)
